@@ -1,22 +1,23 @@
 /*
-SPDX-FileCopyrightText: 2002-2004,2009 Otto Bruggeman <bruggie@gmail.com>
-SPDX-FileCopyrightText: 2007,2010 Kevin Kofler  <kevin.kofler@chello.at>
+    SPDX-FileCopyrightText: 2002-2004,2009 Otto Bruggeman <bruggie@gmail.com>
+    SPDX-FileCopyrightText: 2007,2010 Kevin Kofler  <kevin.kofler@chello.at>
 
-SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "parserbase.h"
 
+// lib
+#include "difference.h"
+#include "diffhunk.h"
+#include "diffmodel.h"
+#include "diffmodellist.h"
+#include "modellist.h"
+#include <komparediff2_logging.h>
+// Qt
 #include <QObject>
 
-#include <komparediffdebug.h>
-#include "diffmodellist.h"
-#include "diffmodel.h"
-#include "diffhunk.h"
-#include "difference.h"
-#include "komparemodellist.h"
-
-using namespace Diff2;
+using namespace KompareDiff2;
 
 // static
 QString ParserBase::unescapePath(QString path)
@@ -54,21 +55,17 @@ QString ParserBase::escapePath(QString path)
     return path;
 }
 
-ParserBase::ParserBase(const KompareModelList* list, const QStringList& diff) :
-    m_diffLines(diff),
-    m_currentModel(nullptr),
-    m_models(nullptr),
-    m_diffIterator(m_diffLines.begin()),
-    m_singleFileDiff(false),
-    m_malformed(false),
-    m_list(list)
+ParserBase::ParserBase(const ModelList *list, const QStringList &diff)
+    : m_diffLines(diff)
+    , m_diffIterator(m_diffLines.begin())
+    , m_list(list)
 {
-//     qCDebug(LIBKOMPAREDIFF2) << diff;
-//     qCDebug(LIBKOMPAREDIFF2) << m_diffLines;
+//     qCDebug(KOMPAREDIFF2_LOG) << diff;
+//     qCDebug(KOMPAREDIFF2_LOG) << m_diffLines;
     m_models = new DiffModelList();
 
     // used in contexthunkheader
-    m_contextHunkHeader1.setPattern(QRegularExpression::anchoredPattern(QStringLiteral("\\*{15} ?(.*)\\n")));  // capture is for function name
+    m_contextHunkHeader1.setPattern(QRegularExpression::anchoredPattern(QStringLiteral("\\*{15} ?(.*)\\n"))); // capture is for function name
     m_contextHunkHeader2.setPattern(QRegularExpression::anchoredPattern(QStringLiteral("\\*\\*\\* ([0-9]+),([0-9]+) \\*\\*\\*\\*.*\\n")));
     // used in contexthunkbody
     m_contextHunkHeader3.setPattern(QRegularExpression::anchoredPattern(QStringLiteral("--- ([0-9]+),([0-9]+) ----\\n")));
@@ -101,30 +98,29 @@ ParserBase::~ParserBase()
         m_models = nullptr; // do not delete this, i pass it around...
 }
 
-enum Kompare::Format ParserBase::determineFormat()
+Format ParserBase::determineFormat()
 {
     // Write your own format detection routine damn it :)
-    return Kompare::UnknownFormat;
+    return UnknownFormat;
 }
 
-DiffModelList* ParserBase::parse(bool* malformed)
+DiffModelList *ParserBase::parse(bool *malformed)
 {
-    DiffModelList* result;
-    switch (determineFormat())
-    {
-    case Kompare::Context :
+    DiffModelList *result;
+    switch (determineFormat()) {
+    case Context:
         result = parseContext();
         break;
-    case Kompare::Ed :
+    case Ed:
         result = parseEd();
         break;
-    case Kompare::Normal :
+    case Normal:
         result = parseNormal();
         break;
-    case Kompare::RCS :
+    case RCS:
         result = parseRCS();
         break;
-    case Kompare::Unified :
+    case Unified:
         result = parseUnified();
         break;
     default: // Unknown and SideBySide for now
@@ -142,23 +138,20 @@ DiffModelList* ParserBase::parse(bool* malformed)
 
 bool ParserBase::parseContextDiffHeader()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseContextDiffHeader()";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseContextDiffHeader()";
     bool result = false;
 
-    while (m_diffIterator != m_diffLines.end())
-    {
+    while (m_diffIterator != m_diffLines.end()) {
         const auto contextDiffHeader1Match = m_contextDiffHeader1.match(*(m_diffIterator)++);
-        if (!contextDiffHeader1Match.hasMatch())
-        {
+        if (!contextDiffHeader1Match.hasMatch()) {
             continue;
         }
-//         qCDebug(LIBKOMPAREDIFF2) << "Matched length Header1 = " << contextDiffHeader1Match.capturedLength();
-//         qCDebug(LIBKOMPAREDIFF2) << "Matched string Header1 = " << contextDiffHeader1Match.captured( 0 );
+//         qCDebug(KOMPAREDIFF2_LOG) << "Matched length Header1 = " << contextDiffHeader1Match.capturedLength();
+//         qCDebug(KOMPAREDIFF2_LOG) << "Matched string Header1 = " << contextDiffHeader1Match.captured( 0 );
         const auto contextDiffHeader2Match = m_contextDiffHeader2.match(*m_diffIterator);
-        if (m_diffIterator != m_diffLines.end() && contextDiffHeader2Match.hasMatch())
-        {
-//             qCDebug(LIBKOMPAREDIFF2) << "Matched length Header2 = " << contextDiffHeader2Match.capturedLength();
-//             qCDebug(LIBKOMPAREDIFF2) << "Matched string Header2 = " << contextDiffHeader2Match.captured( 0 );
+        if (m_diffIterator != m_diffLines.end() && contextDiffHeader2Match.hasMatch()) {
+//             qCDebug(KOMPAREDIFF2_LOG) << "Matched length Header2 = " << contextDiffHeader2Match.capturedLength();
+//             qCDebug(KOMPAREDIFF2_LOG) << "Matched string Header2 = " << contextDiffHeader2Match.captured( 0 );
 
             m_currentModel = new DiffModel(unescapePath(contextDiffHeader1Match.captured(1)), unescapePath(contextDiffHeader2Match.captured(1)));
             m_currentModel->setSourceTimestamp(contextDiffHeader1Match.captured(3));
@@ -170,9 +163,7 @@ bool ParserBase::parseContextDiffHeader()
             result = true;
 
             break;
-        }
-        else
-        {
+        } else {
             // We're screwed, second line does not match or is not there...
             break;
         }
@@ -191,16 +182,14 @@ bool ParserBase::parseEdDiffHeader()
 
 bool ParserBase::parseNormalDiffHeader()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseNormalDiffHeader()";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseNormalDiffHeader()";
     bool result = false;
 
-    while (m_diffIterator != m_diffLines.end())
-    {
+    while (m_diffIterator != m_diffLines.end()) {
         const auto normalDiffHeaderMatch = m_normalDiffHeader.match(*m_diffIterator);
-        if (normalDiffHeaderMatch.hasMatch())
-        {
-//             qCDebug(LIBKOMPAREDIFF2) << "Matched length Header = " << normalDiffHeaderMatch.capturedLength();
-//             qCDebug(LIBKOMPAREDIFF2) << "Matched string Header = " << normalDiffHeaderMatch.captured( 0 );
+        if (normalDiffHeaderMatch.hasMatch()) {
+//             qCDebug(KOMPAREDIFF2_LOG) << "Matched length Header = " << normalDiffHeaderMatch.capturedLength();
+//             qCDebug(KOMPAREDIFF2_LOG) << "Matched string Header = " << normalDiffHeaderMatch.captured( 0 );
 
             m_currentModel = new DiffModel();
             m_currentModel->setSourceFile(unescapePath(normalDiffHeaderMatch.captured(1)));
@@ -210,16 +199,13 @@ bool ParserBase::parseNormalDiffHeader()
 
             ++m_diffIterator;
             break;
-        }
-        else
-        {
-            qCDebug(LIBKOMPAREDIFF2) << "No match for: " << (*m_diffIterator);
+        } else {
+            qCDebug(KOMPAREDIFF2_LOG) << "No match for: " << (*m_diffIterator);
         }
         ++m_diffIterator;
     }
 
-    if (result == false)
-    {
+    if (result == false) {
         // Set this to the first line again and hope it is a single file diff
         m_diffIterator = m_diffLines.begin();
         m_currentModel = new DiffModel();
@@ -236,23 +222,21 @@ bool ParserBase::parseRCSDiffHeader()
 
 bool ParserBase::parseUnifiedDiffHeader()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseUnifiedDiffHeader()";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseUnifiedDiffHeader()";
     bool result = false;
 
-    while (m_diffIterator != m_diffLines.end())   // do not assume we start with the diffheader1 line
+    while (m_diffIterator != m_diffLines.end()) // do not assume we start with the diffheader1 line
     {
         const auto unifiedDiffHeader1Match = m_unifiedDiffHeader1.match(*m_diffIterator);
-        if (!unifiedDiffHeader1Match.hasMatch())
-        {
+        if (!unifiedDiffHeader1Match.hasMatch()) {
             ++m_diffIterator;
             continue;
         }
-//         qCDebug(LIBKOMPAREDIFF2) << "Matched length Header1 = " << unifiedDiffHeader1Match.capturedLength();
-//         qCDebug(LIBKOMPAREDIFF2) << "Matched string Header1 = " << unifiedDiffHeader1Match.captured( 0 );
+//         qCDebug(KOMPAREDIFF2_LOG) << "Matched length Header1 = " << unifiedDiffHeader1Match.capturedLength();
+//         qCDebug(KOMPAREDIFF2_LOG) << "Matched string Header1 = " << unifiedDiffHeader1Match.captured( 0 );
         ++m_diffIterator;
         const auto unifiedDiffHeader2Match = m_unifiedDiffHeader2.match(*m_diffIterator);
-        if (m_diffIterator != m_diffLines.end() && unifiedDiffHeader2Match.hasMatch())
-        {
+        if (m_diffIterator != m_diffLines.end() && unifiedDiffHeader2Match.hasMatch()) {
             m_currentModel = new DiffModel(unescapePath(unifiedDiffHeader1Match.captured(1)), unescapePath(unifiedDiffHeader2Match.captured(1)));
             m_currentModel->setSourceTimestamp(unifiedDiffHeader1Match.captured(2));
             m_currentModel->setSourceRevision(unifiedDiffHeader1Match.captured(4));
@@ -263,9 +247,7 @@ bool ParserBase::parseUnifiedDiffHeader()
             result = true;
 
             break;
-        }
-        else
-        {
+        } else {
             // We're screwed, second line does not match or is not there...
             break;
         }
@@ -276,7 +258,7 @@ bool ParserBase::parseUnifiedDiffHeader()
 
 bool ParserBase::parseContextHunkHeader()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseContextHunkHeader()";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseContextHunkHeader()";
 
     if (m_diffIterator == m_diffLines.end())
         return false;
@@ -306,23 +288,16 @@ bool ParserBase::parseEdHunkHeader()
 
 bool ParserBase::parseNormalHunkHeader()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseNormalHunkHeader()";
-    if (m_diffIterator != m_diffLines.end())
-    {
-//         qCDebug(LIBKOMPAREDIFF2) << "Header = " << *m_diffIterator;
-        if (m_normalHunkHeaderAddedMatch = m_normalHunkHeaderAdded.match(*m_diffIterator); m_normalHunkHeaderAddedMatch.hasMatch())
-        {
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseNormalHunkHeader()";
+    if (m_diffIterator != m_diffLines.end()) {
+//         qCDebug(KOMPAREDIFF2_LOG) << "Header = " << *m_diffIterator;
+        if (m_normalHunkHeaderAddedMatch = m_normalHunkHeaderAdded.match(*m_diffIterator); m_normalHunkHeaderAddedMatch.hasMatch()) {
             m_normalDiffType = Difference::Insert;
-        }
-        else if (m_normalHunkHeaderRemovedMatch = m_normalHunkHeaderRemoved.match(*m_diffIterator); m_normalHunkHeaderRemovedMatch.hasMatch())
-        {
+        } else if (m_normalHunkHeaderRemovedMatch = m_normalHunkHeaderRemoved.match(*m_diffIterator); m_normalHunkHeaderRemovedMatch.hasMatch()) {
             m_normalDiffType = Difference::Delete;
-        }
-        else if (m_normalHunkHeaderChangedMatch = m_normalHunkHeaderChanged.match(*m_diffIterator); m_normalHunkHeaderChangedMatch.hasMatch())
-        {
+        } else if (m_normalHunkHeaderChangedMatch = m_normalHunkHeaderChanged.match(*m_diffIterator); m_normalHunkHeaderChangedMatch.hasMatch()) {
             m_normalDiffType = Difference::Change;
-        }
-        else
+        } else
             return false;
 
         ++m_diffIterator;
@@ -339,28 +314,27 @@ bool ParserBase::parseRCSHunkHeader()
 
 bool ParserBase::parseUnifiedHunkHeader()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseUnifiedHunkHeader()";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseUnifiedHunkHeader()";
 
-    if (m_diffIterator != m_diffLines.end())
-    {
+    if (m_diffIterator != m_diffLines.end()) {
         m_unifiedHunkHeaderMatch = m_unifiedHunkHeader.match(*m_diffIterator);
         if (m_unifiedHunkHeaderMatch.hasMatch()) {
             ++m_diffIterator;
             return true;
         }
     }
-//     qCDebug(LIBKOMPAREDIFF2) << "This is not a unified hunk header : " << (*m_diffIterator);
+//     qCDebug(KOMPAREDIFF2_LOG) << "This is not a unified hunk header : " << (*m_diffIterator);
     return false;
 }
 
 bool ParserBase::parseContextHunkBody()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseContextHunkBody()";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseContextHunkBody()";
 
     // Storing the src part of the hunk for later use
     QStringList oldLines;
     for (; m_diffIterator != m_diffLines.end() && m_contextHunkBodyLine.match(*m_diffIterator).hasMatch(); ++m_diffIterator) {
-//         qCDebug(LIBKOMPAREDIFF2) << "Added old line: " << *m_diffIterator;
+//         qCDebug(KOMPAREDIFF2_LOG) << "Added old line: " << *m_diffIterator;
         oldLines.append(*m_diffIterator);
     }
 
@@ -373,88 +347,76 @@ bool ParserBase::parseContextHunkBody()
     // Storing the dest part of the hunk for later use
     QStringList newLines;
     for (; m_diffIterator != m_diffLines.end() && m_contextHunkBodyLine.match(*m_diffIterator).hasMatch(); ++m_diffIterator) {
-//         qCDebug(LIBKOMPAREDIFF2) << "Added new line: " << *m_diffIterator;
+//         qCDebug(KOMPAREDIFF2_LOG) << "Added new line: " << *m_diffIterator;
         newLines.append(*m_diffIterator);
     }
 
     QString function = m_contextHunkHeader1Match.captured(1);
-//     qCDebug(LIBKOMPAREDIFF2) << "Captured function: " << function;
-    int linenoA      = m_contextHunkHeader2Match.captured(1).toInt();
-//     qCDebug(LIBKOMPAREDIFF2) << "Source line number: " << linenoA;
-    int linenoB      = contextHunkHeader3Match.captured(1).toInt();
-//     qCDebug(LIBKOMPAREDIFF2) << "Dest   line number: " << linenoB;
+//     qCDebug(KOMPAREDIFF2_LOG) << "Captured function: " << function;
+    int linenoA = m_contextHunkHeader2Match.captured(1).toInt();
+//     qCDebug(KOMPAREDIFF2_LOG) << "Source line number: " << linenoA;
+    int linenoB = contextHunkHeader3Match.captured(1).toInt();
+//     qCDebug(KOMPAREDIFF2_LOG) << "Dest   line number: " << linenoB;
 
-    DiffHunk* hunk = new DiffHunk(linenoA, linenoB, function);
+    DiffHunk *hunk = new DiffHunk(linenoA, linenoB, function);
 
     m_currentModel->addHunk(hunk);
 
     QStringList::Iterator oldIt = oldLines.begin();
     QStringList::Iterator newIt = newLines.begin();
 
-    Difference* diff;
-    while (oldIt != oldLines.end() || newIt != newLines.end())
-    {
-        if (oldIt != oldLines.end() && m_contextHunkBodyRemoved.match(*oldIt).hasMatch())
-        {
-//             qCDebug(LIBKOMPAREDIFF2) << "Delete: ";
+    Difference *diff;
+    while (oldIt != oldLines.end() || newIt != newLines.end()) {
+        if (oldIt != oldLines.end() && m_contextHunkBodyRemoved.match(*oldIt).hasMatch()) {
+//             qCDebug(KOMPAREDIFF2_LOG) << "Delete: ";
             diff = new Difference(linenoA, linenoB);
             diff->setType(Difference::Delete);
             m_currentModel->addDiff(diff);
-//             qCDebug(LIBKOMPAREDIFF2) << "Difference added";
+//             qCDebug(KOMPAREDIFF2_LOG) << "Difference added";
             hunk->add(diff);
-            for (; oldIt != oldLines.end(); ++oldIt)
-            {
+            for (; oldIt != oldLines.end(); ++oldIt) {
                 const auto contextHunkBodyRemovedMatch = m_contextHunkBodyRemoved.match(*oldIt);
                 if (!contextHunkBodyRemovedMatch.hasMatch()) {
                     break;
                 }
-//                 qCDebug(LIBKOMPAREDIFF2) << " " << contextHunkBodyRemovedMatch.captured( 1 );
+//                 qCDebug(KOMPAREDIFF2_LOG) << " " << contextHunkBodyRemovedMatch.captured( 1 );
                 diff->addSourceLine(contextHunkBodyRemovedMatch.captured(1));
                 ++linenoA;
             }
-        }
-        else if (newIt != newLines.end() && m_contextHunkBodyAdded.match(*newIt).hasMatch())
-        {
-//             qCDebug(LIBKOMPAREDIFF2) << "Insert: ";
+        } else if (newIt != newLines.end() && m_contextHunkBodyAdded.match(*newIt).hasMatch()) {
+//             qCDebug(KOMPAREDIFF2_LOG) << "Insert: ";
             diff = new Difference(linenoA, linenoB);
             diff->setType(Difference::Insert);
             m_currentModel->addDiff(diff);
-//             qCDebug(LIBKOMPAREDIFF2) << "Difference added";
+//             qCDebug(KOMPAREDIFF2_LOG) << "Difference added";
             hunk->add(diff);
-            for (; newIt != newLines.end(); ++newIt)
-            {
+            for (; newIt != newLines.end(); ++newIt) {
                 const auto contextHunkBodyAddedMatch = m_contextHunkBodyAdded.match(*newIt);
                 if (!contextHunkBodyAddedMatch.hasMatch()) {
                     break;
                 }
-//                 qCDebug(LIBKOMPAREDIFF2) << " " << contextHunkBodyAddedMatch.captured( 1 );
+//                 qCDebug(KOMPAREDIFF2_LOG) << " " << contextHunkBodyAddedMatch.captured( 1 );
                 diff->addDestinationLine(contextHunkBodyAddedMatch.captured(1));
                 ++linenoB;
             }
-        }
-        else if ((oldIt == oldLines.end() || m_contextHunkBodyContext.match(*oldIt).hasMatch()) &&
-                 (newIt == newLines.end() || m_contextHunkBodyContext.match(*newIt).hasMatch()))
-        {
-//             qCDebug(LIBKOMPAREDIFF2) << "Unchanged: ";
+        } else if ((oldIt == oldLines.end() || m_contextHunkBodyContext.match(*oldIt).hasMatch())
+                   && (newIt == newLines.end() || m_contextHunkBodyContext.match(*newIt).hasMatch())) {
+//             qCDebug(KOMPAREDIFF2_LOG) << "Unchanged: ";
             diff = new Difference(linenoA, linenoB);
             // Do not add this diff with addDiff to the model... no unchanged differences allowed in there...
             diff->setType(Difference::Unchanged);
             hunk->add(diff);
-            while ((oldIt == oldLines.end() || m_contextHunkBodyContext.match(*oldIt).hasMatch()) &&
-                    (newIt == newLines.end() || m_contextHunkBodyContext.match(*newIt).hasMatch()) &&
-                    (oldIt != oldLines.end() || newIt != newLines.end()))
-            {
+            while ((oldIt == oldLines.end() || m_contextHunkBodyContext.match(*oldIt).hasMatch())
+                   && (newIt == newLines.end() || m_contextHunkBodyContext.match(*newIt).hasMatch()) && (oldIt != oldLines.end() || newIt != newLines.end())) {
                 QString l;
-                if (oldIt != oldLines.end())
-                {
+                if (oldIt != oldLines.end()) {
                     l = m_contextHunkBodyContext.match(*oldIt).captured(1);
-//                     qCDebug(LIBKOMPAREDIFF2) << "old: " << l;
+//                     qCDebug(KOMPAREDIFF2_LOG) << "old: " << l;
                     ++oldIt;
                 }
-                if (newIt != newLines.end())
-                {
+                if (newIt != newLines.end()) {
                     l = m_contextHunkBodyContext.match(*newIt).captured(1);
-//                     qCDebug(LIBKOMPAREDIFF2) << "new: " << l;
+//                     qCDebug(KOMPAREDIFF2_LOG) << "new: " << l;
                     ++newIt;
                 }
                 diff->addSourceLine(l);
@@ -462,40 +424,35 @@ bool ParserBase::parseContextHunkBody()
                 ++linenoA;
                 ++linenoB;
             }
-        }
-        else if ((oldIt != oldLines.end() && m_contextHunkBodyChanged.match(*oldIt).hasMatch()) ||
-                 (newIt != newLines.end() && m_contextHunkBodyChanged.match(*newIt).hasMatch()))
-        {
-//             qCDebug(LIBKOMPAREDIFF2) << "Changed: ";
+        } else if ((oldIt != oldLines.end() && m_contextHunkBodyChanged.match(*oldIt).hasMatch())
+                   || (newIt != newLines.end() && m_contextHunkBodyChanged.match(*newIt).hasMatch())) {
+//             qCDebug(KOMPAREDIFF2_LOG) << "Changed: ";
             diff = new Difference(linenoA, linenoB);
             diff->setType(Difference::Change);
             m_currentModel->addDiff(diff);
-//             qCDebug(LIBKOMPAREDIFF2) << "Difference added";
+//             qCDebug(KOMPAREDIFF2_LOG) << "Difference added";
             hunk->add(diff);
-            while (oldIt != oldLines.end())
-            {
+            while (oldIt != oldLines.end()) {
                 const auto contextHunkBodyChangedMatch = m_contextHunkBodyChanged.match(*oldIt);
                 if (!contextHunkBodyChangedMatch.hasMatch()) {
                     break;
                 }
-//                 qCDebug(LIBKOMPAREDIFF2) << " " << contextHunkBodyChangedMatch.captured( 1 );
+//                 qCDebug(KOMPAREDIFF2_LOG) << " " << contextHunkBodyChangedMatch.captured( 1 );
                 diff->addSourceLine(contextHunkBodyChangedMatch.captured(1));
                 ++linenoA;
                 ++oldIt;
             }
-            while (newIt != newLines.end())
-            {
+            while (newIt != newLines.end()) {
                 const auto contextHunkBodyChangedMatch = m_contextHunkBodyChanged.match(*newIt);
                 if (!contextHunkBodyChangedMatch.hasMatch()) {
                     break;
                 }
-//                 qCDebug(LIBKOMPAREDIFF2) << " " << contextHunkBodyChangedMatch.captured( 1 );
+//                 qCDebug(KOMPAREDIFF2_LOG) << " " << contextHunkBodyChangedMatch.captured( 1 );
                 diff->addDestinationLine(contextHunkBodyChangedMatch.captured(1));
                 ++linenoB;
                 ++newIt;
             }
-        }
-        else
+        } else
             return false;
         diff->determineInlineDifferences();
     }
@@ -510,66 +467,56 @@ bool ParserBase::parseEdHunkBody()
 
 bool ParserBase::parseNormalHunkBody()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseNormalHunkBody";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseNormalHunkBody";
 
     QString type;
 
     int linenoA = 0, linenoB = 0;
 
-    if (m_normalDiffType == Difference::Insert)
-    {
+    if (m_normalDiffType == Difference::Insert) {
         linenoA = m_normalHunkHeaderAddedMatch.captured(1).toInt();
         linenoB = m_normalHunkHeaderAddedMatch.captured(2).toInt();
-    }
-    else if (m_normalDiffType == Difference::Delete)
-    {
+    } else if (m_normalDiffType == Difference::Delete) {
         linenoA = m_normalHunkHeaderRemovedMatch.captured(1).toInt();
         linenoB = m_normalHunkHeaderRemovedMatch.captured(3).toInt();
-    }
-    else if (m_normalDiffType == Difference::Change)
-    {
+    } else if (m_normalDiffType == Difference::Change) {
         linenoA = m_normalHunkHeaderChangedMatch.captured(1).toInt();
         linenoB = m_normalHunkHeaderChangedMatch.captured(3).toInt();
     }
 
-    DiffHunk* hunk = new DiffHunk(linenoA, linenoB);
+    DiffHunk *hunk = new DiffHunk(linenoA, linenoB);
     m_currentModel->addHunk(hunk);
-    Difference* diff = new Difference(linenoA, linenoB);
+    Difference *diff = new Difference(linenoA, linenoB);
     hunk->add(diff);
     m_currentModel->addDiff(diff);
 
     diff->setType(m_normalDiffType);
 
     if (m_normalDiffType == Difference::Change || m_normalDiffType == Difference::Delete)
-        for (; m_diffIterator != m_diffLines.end(); ++m_diffIterator)
-        {
+        for (; m_diffIterator != m_diffLines.end(); ++m_diffIterator) {
             const auto normalHunkBodyRemovedMatch = m_normalHunkBodyRemoved.match(*m_diffIterator);
             if (!normalHunkBodyRemovedMatch.hasMatch()) {
                 break;
             }
-//             qCDebug(LIBKOMPAREDIFF2) << "Line = " << *m_diffIterator;
+//             qCDebug(KOMPAREDIFF2_LOG) << "Line = " << *m_diffIterator;
             diff->addSourceLine(normalHunkBodyRemovedMatch.captured(1));
         }
 
-    if (m_normalDiffType == Difference::Change)
-    {
-        if (m_diffIterator != m_diffLines.end() && m_normalHunkBodyDivider.match(*m_diffIterator).hasMatch())
-        {
-//             qCDebug(LIBKOMPAREDIFF2) << "Line = " << *m_diffIterator;
+    if (m_normalDiffType == Difference::Change) {
+        if (m_diffIterator != m_diffLines.end() && m_normalHunkBodyDivider.match(*m_diffIterator).hasMatch()) {
+//             qCDebug(KOMPAREDIFF2_LOG) << "Line = " << *m_diffIterator;
             ++m_diffIterator;
-        }
-        else
+        } else
             return false;
     }
 
     if (m_normalDiffType == Difference::Insert || m_normalDiffType == Difference::Change)
-        for (; m_diffIterator != m_diffLines.end(); ++m_diffIterator)
-        {
-             const auto normalHunkBodyAddedMatch = m_normalHunkBodyAdded.match(*m_diffIterator);
-             if (!normalHunkBodyAddedMatch.hasMatch()) {
-                 break;
-             }
-//             qCDebug(LIBKOMPAREDIFF2) << "Line = " << *m_diffIterator;
+        for (; m_diffIterator != m_diffLines.end(); ++m_diffIterator) {
+            const auto normalHunkBodyAddedMatch = m_normalHunkBodyAdded.match(*m_diffIterator);
+            if (!normalHunkBodyAddedMatch.hasMatch()) {
+                break;
+            }
+//             qCDebug(KOMPAREDIFF2_LOG) << "Line = " << *m_diffIterator;
             diff->addDestinationLine(normalHunkBodyAddedMatch.captured(1));
         }
 
@@ -581,7 +528,7 @@ bool ParserBase::parseRCSHunkBody()
     return false;
 }
 
-bool ParserBase::matchesUnifiedHunkLine(const QString& line) const
+bool ParserBase::matchesUnifiedHunkLine(const QString &line) const
 {
     static const QChar context = QLatin1Char(' ');
     static const QChar added = QLatin1Char('+');
@@ -594,7 +541,7 @@ bool ParserBase::matchesUnifiedHunkLine(const QString& line) const
 
 bool ParserBase::parseUnifiedHunkBody()
 {
-//     qCDebug(LIBKOMPAREDIFF2) << "ParserBase::parseUnifiedHunkBody";
+//     qCDebug(KOMPAREDIFF2_LOG) << "ParserBase::parseUnifiedHunkBody";
 
     int linenoA = 0, linenoB = 0;
     bool wasNum;
@@ -602,8 +549,7 @@ bool ParserBase::parseUnifiedHunkBody()
     // Fetching the stuff we need from the hunkheader regexp that was parsed in parseUnifiedHunkHeader();
     linenoA = m_unifiedHunkHeaderMatch.captured(1).toInt();
     int lineCountA = 1, lineCountB = 1; // an omitted line count in the header implies a line count of 1
-    if (!m_unifiedHunkHeaderMatch.captured(3).isEmpty())
-    {
+    if (!m_unifiedHunkHeaderMatch.captured(3).isEmpty()) {
         lineCountA = m_unifiedHunkHeaderMatch.captured(3).toInt(&wasNum);
         if (!wasNum)
             return false;
@@ -624,24 +570,21 @@ bool ParserBase::parseUnifiedHunkBody()
     }
     QString function = m_unifiedHunkHeaderMatch.captured(7);
 
-    DiffHunk* hunk = new DiffHunk(linenoA, linenoB, function);
+    DiffHunk *hunk = new DiffHunk(linenoA, linenoB, function);
     m_currentModel->addHunk(hunk);
 
     const QStringList::ConstIterator m_diffLinesEnd = m_diffLines.end();
 
     const QString context = QStringLiteral(" ");
-    const QString added   = QStringLiteral("+");
+    const QString added = QStringLiteral("+");
     const QString removed = QStringLiteral("-");
 
-    while (m_diffIterator != m_diffLinesEnd && matchesUnifiedHunkLine(*m_diffIterator) && (lineCountA || lineCountB))
-    {
-        Difference* diff = new Difference(linenoA, linenoB);
+    while (m_diffIterator != m_diffLinesEnd && matchesUnifiedHunkLine(*m_diffIterator) && (lineCountA || lineCountB)) {
+        Difference *diff = new Difference(linenoA, linenoB);
         hunk->add(diff);
 
-        if ((*m_diffIterator).startsWith(context))
-        {   // context
-            for (; m_diffIterator != m_diffLinesEnd && (*m_diffIterator).startsWith(context) && (lineCountA || lineCountB); ++m_diffIterator)
-            {
+        if ((*m_diffIterator).startsWith(context)) { // context
+            for (; m_diffIterator != m_diffLinesEnd && (*m_diffIterator).startsWith(context) && (lineCountA || lineCountB); ++m_diffIterator) {
                 diff->addSourceLine(QString(*m_diffIterator).remove(0, 1));
                 diff->addDestinationLine(QString(*m_diffIterator).remove(0, 1));
                 ++linenoA;
@@ -649,35 +592,26 @@ bool ParserBase::parseUnifiedHunkBody()
                 --lineCountA;
                 --lineCountB;
             }
-        }
-        else
-        {   // This is a real difference, not context
-            for (; m_diffIterator != m_diffLinesEnd && (*m_diffIterator).startsWith(removed) && (lineCountA || lineCountB); ++m_diffIterator)
-            {
+        } else { // This is a real difference, not context
+            for (; m_diffIterator != m_diffLinesEnd && (*m_diffIterator).startsWith(removed) && (lineCountA || lineCountB); ++m_diffIterator) {
                 diff->addSourceLine(QString(*m_diffIterator).remove(0, 1));
                 ++linenoA;
                 --lineCountA;
             }
-            for (; m_diffIterator != m_diffLinesEnd && (*m_diffIterator).startsWith(added) && (lineCountA || lineCountB); ++m_diffIterator)
-            {
+            for (; m_diffIterator != m_diffLinesEnd && (*m_diffIterator).startsWith(added) && (lineCountA || lineCountB); ++m_diffIterator) {
                 diff->addDestinationLine(QString(*m_diffIterator).remove(0, 1));
                 ++linenoB;
                 --lineCountB;
             }
-            if (diff->sourceLineCount() == 0)
-            {
+            if (diff->sourceLineCount() == 0) {
                 diff->setType(Difference::Insert);
-//                 qCDebug(LIBKOMPAREDIFF2) << "Insert difference";
-            }
-            else if (diff->destinationLineCount() == 0)
-            {
+//                 qCDebug(KOMPAREDIFF2_LOG) << "Insert difference";
+            } else if (diff->destinationLineCount() == 0) {
                 diff->setType(Difference::Delete);
-//                 qCDebug(LIBKOMPAREDIFF2) << "Delete difference";
-            }
-            else
-            {
+//                 qCDebug(KOMPAREDIFF2_LOG) << "Delete difference";
+            } else {
                 diff->setType(Difference::Change);
-//                 qCDebug(LIBKOMPAREDIFF2) << "Change difference";
+//                 qCDebug(KOMPAREDIFF2_LOG) << "Change difference";
             }
             diff->determineInlineDifferences();
             m_currentModel->addDiff(diff);
@@ -687,20 +621,21 @@ bool ParserBase::parseUnifiedHunkBody()
     return true;
 }
 
-void ParserBase::checkHeader(const QRegularExpression& header)
+void ParserBase::checkHeader(const QRegularExpression &header)
 {
-    if (m_diffIterator != m_diffLines.end()
-            && !header.match(*m_diffIterator).hasMatch()
-            && !m_diffIterator->startsWith(QLatin1String("Index: ")) /* SVN diff */
-            && !m_diffIterator->startsWith(QLatin1String("diff ")) /* concatenated diff */
-            && !m_diffIterator->startsWith(QLatin1String("-- ")) /* git format-patch */)
+    // clang-format off
+    if (m_diffIterator != m_diffLines.end() &&
+        !header.match(*m_diffIterator).hasMatch() &&
+        !m_diffIterator->startsWith(QLatin1String("Index: ")) && /* SVN diff */
+        !m_diffIterator->startsWith(QLatin1String("diff ")) && /* concatenated diff */
+        !m_diffIterator->startsWith(QLatin1String("-- ")) /* git format-patch */)
+    // clang-format on
         m_malformed = true;
 }
 
-DiffModelList* ParserBase::parseContext()
+DiffModelList *ParserBase::parseContext()
 {
-    while (parseContextDiffHeader())
-    {
+    while (parseContextDiffHeader()) {
         while (parseContextHunkHeader())
             parseContextHunkBody();
         if (m_currentModel->differenceCount() > 0)
@@ -710,21 +645,17 @@ DiffModelList* ParserBase::parseContext()
 
     m_models->sort();
 
-    if (m_models->count() > 0)
-    {
+    if (m_models->count() > 0) {
         return m_models;
-    }
-    else
-    {
+    } else {
         delete m_models;
         return nullptr;
     }
 }
 
-DiffModelList* ParserBase::parseEd()
+DiffModelList *ParserBase::parseEd()
 {
-    while (parseEdDiffHeader())
-    {
+    while (parseEdDiffHeader()) {
         while (parseEdHunkHeader())
             parseEdHunkBody();
         if (m_currentModel->differenceCount() > 0)
@@ -733,21 +664,17 @@ DiffModelList* ParserBase::parseEd()
 
     m_models->sort();
 
-    if (m_models->count() > 0)
-    {
+    if (m_models->count() > 0) {
         return m_models;
-    }
-    else
-    {
+    } else {
         delete m_models;
         return nullptr;
     }
 }
 
-DiffModelList* ParserBase::parseNormal()
+DiffModelList *ParserBase::parseNormal()
 {
-    while (parseNormalDiffHeader())
-    {
+    while (parseNormalDiffHeader()) {
         while (parseNormalHunkHeader())
             parseNormalHunkBody();
         if (m_currentModel->differenceCount() > 0)
@@ -755,8 +682,7 @@ DiffModelList* ParserBase::parseNormal()
         checkHeader(m_normalDiffHeader);
     }
 
-    if (m_singleFileDiff)
-    {
+    if (m_singleFileDiff) {
         while (parseNormalHunkHeader())
             parseNormalHunkBody();
         if (m_currentModel->differenceCount() > 0)
@@ -767,21 +693,17 @@ DiffModelList* ParserBase::parseNormal()
 
     m_models->sort();
 
-    if (m_models->count() > 0)
-    {
+    if (m_models->count() > 0) {
         return m_models;
-    }
-    else
-    {
+    } else {
         delete m_models;
         return nullptr;
     }
 }
 
-DiffModelList* ParserBase::parseRCS()
+DiffModelList *ParserBase::parseRCS()
 {
-    while (parseRCSDiffHeader())
-    {
+    while (parseRCSDiffHeader()) {
         while (parseRCSHunkHeader())
             parseRCSHunkBody();
         if (m_currentModel->differenceCount() > 0)
@@ -790,25 +712,21 @@ DiffModelList* ParserBase::parseRCS()
 
     m_models->sort();
 
-    if (m_models->count() > 0)
-    {
+    if (m_models->count() > 0) {
         return m_models;
-    }
-    else
-    {
+    } else {
         delete m_models;
         return nullptr;
     }
 }
 
-DiffModelList* ParserBase::parseUnified()
+DiffModelList *ParserBase::parseUnified()
 {
-    while (parseUnifiedDiffHeader())
-    {
+    while (parseUnifiedDiffHeader()) {
         while (parseUnifiedHunkHeader())
             parseUnifiedHunkBody();
-//         qCDebug(LIBKOMPAREDIFF2) << "New model ready to be analyzed...";
-//         qCDebug(LIBKOMPAREDIFF2) << " differenceCount() == " << m_currentModel->differenceCount();
+//         qCDebug(KOMPAREDIFF2_LOG) << "New model ready to be analyzed...";
+//         qCDebug(KOMPAREDIFF2_LOG) << " differenceCount() == " << m_currentModel->differenceCount();
         if (m_currentModel->differenceCount() > 0)
             m_models->append(m_currentModel);
         checkHeader(m_unifiedDiffHeader1);
@@ -816,14 +734,10 @@ DiffModelList* ParserBase::parseUnified()
 
     m_models->sort();
 
-    if (m_models->count() > 0)
-    {
+    if (m_models->count() > 0) {
         return m_models;
-    }
-    else
-    {
+    } else {
         delete m_models;
         return nullptr;
     }
 }
-
